# Inverted Index

<!-- [![PyPi Version](https://img.shields.io/pypi/v/inverted-index)](https://pypi.org/project/inverted-index/) -->

<!-- [![Actions Status](https://github.com/blester125/inverted-index/workflows/Unit%20Test/badge.svg)](https://github.com/blester125/inverted-index/actions) -->

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
